==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-cq/src/integrationTest/java/org/apache/geode/codeAnalysis/AnalyzeCQSerializablesIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.codeAnalysis;

import java.util.Optional;

import org.junit.experimental.categories.Category;

import org.apache.geode.cache.query.cq.internal.CQSanctionedSerializablesService;
import org.apache.geode.test.junit.categories.ClientSubscriptionTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({ClientSubscriptionTest.class, SerializationTest.class})
public class AnalyzeCQSerializablesIntegrationTest extends AnalyzeSerializablesJUnitTestBase {

  @Override
  protected String getModuleName() {
    return "geode-cq";
  }

  @Override
  protected Optional<Class<?>> getModuleClass() {
    return Optional.of(CQSanctionedSerializablesService.class);
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-cq/src/integrationTest/java/org/apache/geode/codeAnalysis/AnalyzeCQSerializablesIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.codeAnalysis;

import java.util.Optional;

import org.junit.experimental.categories.Category;

import org.apache.geode.cache.query.cq.internal.CQSanctionedSerializablesService;
import org.apache.geode.test.junit.categories.ClientSubscriptionTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({ClientSubscriptionTest.class, SerializationTest.class})
public class AnalyzeCQSerializablesIntegrationTest
    extends AnalyzeSerializablesWithClassAnalysisRuleTestBase {

  @Override
  protected String getModuleName() {
    return "geode-cq";
  }

  @Override
  protected Optional<Class<?>> getModuleClass() {
    return Optional.of(CQSanctionedSerializablesService.class);
  }
}
